@@ -549,14 +549,14 @@ class Project(object):
                 long_name = process.name
                 stub = process.name[:max_length - digits]
                 short_number = len(stub_map.get(stub, []))
-                short_name = '{stub}{short_number:04d}'.format(**locals())
+                short_name = '{stub}{short_number:04d}'
                 stub_map.setdefault(stub, []).append((short_name, long_name))
                 abbreviation_map[short_name] = long_name
                 fullform_map[long_name] = short_name
 
                 process.name = short_name
 
-        with open('abbreviations_{self.meta.model_name}.dat'.format(**locals()), 'w') as outfile:
+        with open('abbreviations_{self.meta.model_name}.dat', 'w') as outfile:
             outfile.write(pprint.pformat(stub_map))
 
     def save(self, filename=None, validate=True):
@@ -888,9 +888,9 @@ class Project(object):
                                      for i in
                                      child.attrib['cell_size'].split()])
                     if len(cell) == 3:
-                        self.layer_list.cell = np.diag(cell)
+                        self.layer_list.cell = np.diag(np.array(cell))
                     elif len(cell) == 9:
-                        self.layer_list.cell = cell.reshape(3, 3)
+                        self.layer_list.cell = np.array(cell).reshape(3, 3)
                     else:
                         raise UserWarning('%s not understood' % cell)
                     self.layer_list.default_layer = \
@@ -1448,11 +1448,13 @@ class LayerList(FixedObject, list):
             if value:
                 from kmos.utils import get_ase_constructor
                 from ase.atoms import Atoms
-                print("line 1451", value)
                 value = eval(value)
                 if (not hasattr(self, 'representation') or
                         not self.representation):
-                    self.cell = value[0].cell
+                    try:# if it's a list or a tuple, then take first value.
+                        self.cell = value[0].get_cell()
+                    except:
+                        self.cell = value.get_cell()
                 value = '[%s]' % get_ase_constructor(value)
             self.__dict__[key] = '%s' % value
         else:
@@ -1475,7 +1477,7 @@ class LayerList(FixedObject, list):
             raise UserWarning('No Layer named %s found.' % layer_name)
 
         if site_name is not None and not any([re.search(site_name, x) for x in ['_'.join(x.name.split('_')) for x in layer.sites]]):
-            raise UserWarning('Layer {layer_name} has no site matching {site_name}. Please check spelling and try again.'.format(**locals()))
+            raise UserWarning('Layer {layer_name} has no site matching {site_name}. Please check spelling and try again.')
 
         if site_name is None:
             return [
